RunWorkflows() has moved to workr::RunWorkflows(). This wrapper remains
for backward compatibility in {gsm.core}.
Usage
RunWorkflows(
lWorkflows,
lData = NULL,
lConfig = NULL,
bKeepInputData = FALSE,
bReturnResult = TRUE,
strResultNames = c("Type", "ID")
)Arguments
- lWorkflows
listA named list of metadata defining how the workflow should be run.- lData
listA named list of domain-level data frames.- lConfig
listA configuration object with two methods:LoadData: A function that loads data specified inlWorkflow$spec.SaveData: A function that saves data returned by the last step inlWorkflow$steps.
- bKeepInputData
booleanshould the input data be included inlDataafter the workflow is run? Only relevant when bReturnResult is FALSE. Default isTRUE.- bReturnResult
booleanshould only the result from the last step (lResults) be returned? If false, the full workflow (includinglResults) is returned. Default isTRUE.- strResultNames
stringvector of length two, which describes the meta fields used to name the output.
Value
A named list of results from RunWorkflow(), where the names correspond to the names of
the workflow ID